==> haskell-language-python-0.5.4-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.4
id: language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR
key: language-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR
license: BSD3
copyright: (c) 2008-2016 Bernard James Pope
maintainer: florbitous@gmail.com
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
author: Bernard James Pope (Bernie Pope)
exposed: True
indefinite: False
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
abi: 260621c833bcd3b10b94797ae499e508
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/language-python-0.5.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/language-python-0.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/language-python-0.5.4
hs-libraries: HSlanguage-python-0.5.4-8C5yVPTZS4cEoKsquoNSKR
depends:
    array-0.5.2.0 base-4.10.1.0 containers-0.5.10.2
    monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz pretty-1.1.3.3
    transformers-0.5.2.0 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             monads-tf-0.1.0.3-1scKDck1nyF3hHYXqW7mNz=0c9b66ce3d9f82342ac301838c6515b5
             pretty-1.1.3.3=229bcf5342145ac1755207fe83d29780
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-python-0.5.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-language-python.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-python
version: 0.5.4
id: language-python-0.5.4-Jc0vhA1M7R1CXsovtYdNkb
key: language-python-0.5.4-Jc0vhA1M7R1CXsovtYdNkb
license: BSD-3-Clause
copyright: (c) 2008-2016 Bernard James Pope
maintainer: florbitous@gmail.com
author: Bernard James Pope (Bernie Pope)
stability: experimental
homepage: http://github.com/bjpop/language-python
synopsis: Parsing and pretty printing of Python code.
description:
    language-python is a Haskell library for lexical analysis, parsing
    and pretty printing Python code. It supports versions 2.x and 3.x of Python.
category: Language
abi: ca02583c1358613d525096aba6e7bcc3
exposed: True
exposed-modules:
    Language.Python.Common Language.Python.Common.AST
    Language.Python.Common.ParseError
    Language.Python.Common.ParserMonad Language.Python.Common.Pretty
    Language.Python.Common.PrettyAST
    Language.Python.Common.PrettyParseError
    Language.Python.Common.PrettyToken
    Language.Python.Common.SrcLocation
    Language.Python.Common.StringEscape Language.Python.Common.Token
    Language.Python.Version2 Language.Python.Version2.Lexer
    Language.Python.Version2.Parser Language.Python.Version3
    Language.Python.Version3.Lexer Language.Python.Version3.Parser
hidden-modules: Language.Python.Common.ParserUtils
                Language.Python.Common.LexerUtils
                Language.Python.Version3.Parser.Parser
                Language.Python.Version3.Parser.Lexer
                Language.Python.Version2.Parser.Parser
                Language.Python.Version2.Parser.Lexer
import-dirs: /usr/lib/ghc-8.4.3/site-local/language-python-0.5.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/language-python-0.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/language-python-0.5.4
hs-libraries: HSlanguage-python-0.5.4-Jc0vhA1M7R1CXsovtYdNkb
depends:
    array-0.5.2.0 base-4.11.1.0 containers-0.5.11.0
    monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU pretty-1.1.3.6
    transformers-0.5.5.0 utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             monads-tf-0.1.0.3-Giaow1Z3bgu7ae1ewXz7xU=186b425acb38e926ddf66c94a3c8e5aa
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
haddock-interfaces: /usr/share/doc/haskell-language-python/html/language-python.haddock
haddock-html: /usr/share/doc/haskell-language-python/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
